@@ -1,9 +1,9 @@
+#line 2 "edit-distance.h.tmpl"
 #ifndef EDIT_DISTANCE_INT_TRANS_H
 #define EDIT_DISTANCE_INT_TRANS_H
-
-int distance_int_trans (const unsigned int * word1,
-                    int len1,
+#line 1 "declaration"
+int distance_int_trans (
                     text_fuzzy_t * tf)
 ;
-
+#line 7 "edit-distance.h.tmpl"
 #endif /* EDIT_DISTANCE_INT_TRANS_H */
